@@ -1,6 +1,4 @@
-import re
-from pathlib import Path
-from typing import TextIO
+from typing import Any, TextIO
 
 import yaml
 
@@ -13,14 +11,10 @@ class YamlFileConfigurationLoader(FileConfigurationLoader):
     Read any configuration from YAML files
     """
 
-    @staticmethod
-    def get_supported_source() -> str:
-        return 'yaml_file'
-
-    def supports(self, source: str) -> bool:
+    def supports(self, source: Any) -> bool:
         return super().supports(source) and \
-            bool(re.match(r'^\.(yaml|yml)$', Path(source).suffix, re.IGNORECASE))
+            Utils.has_extension(source, r'(yaml|yml)')
 
-    @classmethod
-    def _load_file(cls, file: TextIO) -> dict:
+    def _load_file(self, file: TextIO) -> dict:
+        super()._load_file(file)
         return Utils.always_dict(yaml.safe_load(file))
