@@ -1,7 +1,9 @@
 """ Main class """
-from wg_federation.controller.controller_dispatcher import ControllerDispatcher
+
+from wg_federation.controller.controller_events import ControllerEvents
 from wg_federation.di.container import Container
 from wg_federation.input.manager.input_manager import InputManager
+from wg_federation.observer.event_dispatcher import EventDispatcher
 
 
 class Main:
@@ -24,8 +26,11 @@ class Main:
         user_input = input_manager.parse_all()
         self._container.user_input.override(user_input)
 
-        controller_dispatcher: ControllerDispatcher = self._container.controller_dispatcher()
-
-        controller_dispatcher.dispatch_all(user_input)
+        controller_dispatcher: EventDispatcher = self._container.controller_dispatcher()
+        controller_dispatcher.dispatch([
+            ControllerEvents.CONTROLLER_BASELINE,
+            ControllerEvents.CONTROLLER_MAIN,
+            ControllerEvents.CONTROLLER_LATE,
+        ], user_input)
 
         return 0
